@@ -10,7 +10,7 @@ EXIT_FAILURE: int = 1
 
 # TODO: There are many different variations of vim, they need all
 # need to be added to this list
-VIM_VARIENTS: List[str] = ['nvim', 'vim', 'gvim']
+VIM_VARIENTS: List[str] = ['nvim', 'vim', 'gvim', 'neovide']
 
 
 class ThreadSafeMeta(type):
@@ -52,7 +52,7 @@ class Config(metaclass=ThreadSafeMeta):
     the code base
     """
     __package: str = __package__
-    __version: str = "0.1.4"
+    __version: str = "0.1.5"
     __executable: str = "vsm"
     __base_dir: Path = Path(__file__).resolve(strict=True).parent.parent.parent
     __config_dir: Path = Path.home() / ".config" / __package
